@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006 - 2015 René Rebe
+ * Copyright (C) 2006 - 2020 René Rebe
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -143,16 +143,16 @@ int GIFCodec::readImage (std::istream* stream, Image& image, const std::string&
   ColorMap = (GifFile->Image.ColorMap ? GifFile->Image.ColorMap :
 	      GifFile->SColorMap);
   
+  // convert colormap to our 16bit "TIFF"format
   uint16_t rmap [ColorMap->ColorCount];
   uint16_t gmap [ColorMap->ColorCount];
   uint16_t bmap [ColorMap->ColorCount];
   for (int i = 0; i < ColorMap->ColorCount; ++i) {
-    rmap[i] = ColorMap->Colors[i].Red << 8;
-    gmap[i] = ColorMap->Colors[i].Green << 8;
-    bmap[i] = ColorMap->Colors[i].Blue << 8;
+    rmap[i] = 0x101 * ColorMap->Colors[i].Red;
+    gmap[i] = 0x101 * ColorMap->Colors[i].Green;
+    bmap[i] = 0x101 * ColorMap->Colors[i].Blue;
   }
   
-  // convert colormap to our 16bit "TIFF"format
   colorspace_de_palette (image, ColorMap->ColorCount, rmap, gmap, bmap);
   
   EGifCloseFile(GifFile, &GifError);
