@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006 - 2017 René Rebe, ExactCODE GmbH
+ * Copyright (C) 2006 - 2022 René Rebe, ExactCODE GmbH
  *           (C) 2006, 2007 Archivista GmbH, CH-8042 Zuerich
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -341,10 +341,10 @@ int JPEGCodec::readImage (std::istream* stream, Image& image, const std::string&
 	}
 	
 	switch (buffer[1]) {
-	  // types wo/ data
+	  // types w/o data
 	case 0xd9: // EOI
 	  found = true; // cheating
-	  std::cerr << "EOI wo/ SOF segment?" << std::endl;
+	  std::cerr << "EOI w/o SOF segment?" << std::endl;
 	  
 	case 0xd8: // SOI
 	case 0xd0: case 0xd1: case 0xd2: case 0xd3: // RSTn
@@ -471,7 +471,7 @@ bool JPEGCodec::writeImage (std::ostream* stream, Image& image, int quality,
     if (image.bps < 8)
       std::cerr << "JPEGCodec: JPEG can not hold less than 8 bit-per-channel." << std::endl;
     else
-      std::cerr << "Unhandled bps/spp combination." << std::endl;
+      std::cerr << "JPEGCodec: Unhandled bps/spp combination." << std::endl;
     jpeg_destroy_compress(&cinfo);
     return false;
   }
