@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006 - 2015 René Rebe, ExactCODE GmbH
+ * Copyright (C) 2006 - 2023 René Rebe, ExactCODE GmbH
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -126,13 +126,23 @@ int PNMCodec::readImage (std::istream* stream, Image& image, const std::string&
 	    {
 	      if (image.spp == 1) {
 		int i;
-		*stream >> i;
 		
-		i = i * (255 / maxval);
-
-		// only mode 1 is defined with 1 == black, ...
-		if (mode == '1') i = 255 - i;
-
+		// some apps, like Gimp don't white-space 1 bit files
+		if (mode == '1') {
+		  for (i = ' '; isspace(i) && i != std::istream::traits_type::eof();)
+		    i = stream->get();
+		  if (i == std::istream::traits_type::eof()) {
+		    // premature eof
+		    std::cerr << "Premature EOF" << std::endl;
+		    return false;
+		  }
+		  
+		  i = i == '0' ? 255 : 0;
+		} else {
+		  *stream >> i;
+		  i = i * (255 / maxval);
+		}
+		
 		it.setL (i);
 	      }
 	      else {
@@ -156,15 +166,16 @@ int PNMCodec::readImage (std::istream* stream, Image& image, const std::string&
 	{
 	  uint8_t* dest = image.getRawData() + y * stride;
 	  stream->read ((char*)dest, stride);
-
-	  // is it publically defined somewhere???
+	  if (stream->eof()) {
+	    std::cerr << "Premature EOF" << std::endl;
+	    return false;
+	  }
+	  
 	  if (bps == 1) {
 	    uint8_t* xor_ptr = dest;
 	    for (int x = 0; x < image.w; x += 8)
 	      *xor_ptr++ ^= 0xff;
-	  }
-	  
-	  if (bps == 16) {
+	  } else if (bps == 16) {
 	    uint16_t* swap_ptr = (uint16_t*)dest;
 	    for (int x = 0; x < stride/2; ++x, ++swap_ptr)
 	      *swap_ptr = ByteSwap<NativeEndianTraits,BigEndianTraits, uint16_t>::Swap (*swap_ptr);
@@ -190,7 +201,7 @@ bool PNMCodec::writeImage (std::ostream* stream, Image& image, int quality,
   else if (image.spp == 3)
     format = 3;
   else {
-    std::cerr << "Not (yet?) supported PBM format." << std::endl;
+    std::cerr << "NYI PNM sample format." << std::endl;
     return false;
   }
   
@@ -203,7 +214,7 @@ bool PNMCodec::writeImage (std::ostream* stream, Image& image, int quality,
     format += 3;
   
   *stream << "P" << format << std::endl;
-  *stream << "# http://exactcode.com/oss/exactimage/" << std::endl;
+  *stream << "# exactcode.com/exactimage" << std::endl;
 
   *stream << image.w << " " << image.h << std::endl;
   
@@ -217,12 +228,13 @@ bool PNMCodec::writeImage (std::ostream* stream, Image& image, int quality,
   Image::iterator it = image.begin ();
   if (c == "ascii")
     {
+      const bool whitespace = image.bps > 1;
       for (int y = 0; y < image.h; ++y)
 	{
 	  it = it.at(0, y);
 	  for (int x = 0; x < image.w; ++x, ++it)
 	    {
-	      if (x != 0)
+	      if (x != 0 && whitespace)
 		*stream << " ";
 	      
 	      *it;
@@ -261,9 +273,7 @@ bool PNMCodec::writeImage (std::ostream* stream, Image& image, int quality,
 	    uint8_t* xor_ptr = &ptr[0];
 	    for (int x = 0; x < image.w; x += 8)
 	      *xor_ptr++ ^= 0xff;
-	  }
-	  
-	  if (bps == 16) {
+	  } else if (bps == 16) {
 	    uint16_t* swap_ptr = (uint16_t*)&ptr[0];
 	    for (int x = 0; x < stridefill / 2; ++x, ++swap_ptr)
 	      *swap_ptr = ByteSwap<BigEndianTraits, NativeEndianTraits, uint16_t>::Swap (*swap_ptr);
