@@ -1,6 +1,6 @@
 /*
  * The ExactImage library's displayy compatible command line frontend.
- * Copyright (C) 2006 - 2017 René Rebe, ExactCODE GmbH
+ * Copyright (C) 2006 - 2019 René Rebe, ExactCODE GmbH
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,9 +42,9 @@ using namespace Utility;
 #include "Colorspace.hh"
 
 #include "rotate.hh"
-
+#include "scale.hh"
+ 
 #include "edisplay.hh"
-
 #include "Endianess.hh"
 
 using std::cout;
@@ -74,22 +74,32 @@ void Viewer::Zoom (double f)
     evas_image->SmoothScale (true);
     int img_w = evas_image->Width(), img_h = evas_image->Height();
     double sx = evas->OutputWidth(), sy = evas->OutputHeight();
-    // keep aspect
     sx /= img_w;
     sy /= img_h;
-    if (sx >= sy) {
-      img_w = evas->OutputWidth();
-      img_h = sx * img_h;
-    } else {
-      img_w = sy * img_w;
-      img_h = evas->OutputHeight();
+    
+    //std::cerr << img_w << " " << img_h << " " << sx << " " << sy << std::endl;
+    
+    // keep aspect
+    if (sx >= sy) sy = sx;
+    else sx = sy;
+    
+    img_w = sx * img_w;
+    img_h = sy * img_h;
+    
+    // fancy DDT scaling
+    if (false) {
+      ddt_scale(*image, sx, sy);
+      evas_image = ImageToEvas (image, evas_image);
+      evas_image->SmoothScale(false);
     }
+    
     evas_image->Resize (img_w, img_h);
     evas_image->ImageFill(0, 0, img_w, img_h);
     
     // center
-    evas_image->Move((img_w - evas->OutputWidth()) / -2,
-		     (img_h - evas->OutputHeight()) / -2);
+    const int dx = (img_w - evas->OutputWidth()) / -2,
+      dy = (img_h - evas->OutputHeight()) / -2;
+    evas_image->Move(dx, dy);
     return;
   }
   
@@ -162,10 +172,10 @@ void Viewer::Move (int _x, int _y)
 void Viewer::UpdateOSD (const std::string& str1, const std::string& str2)
 {
   if (_root) return;
-  evas_osd_text1->Text (str1);
-  evas_osd_text2->Text (str2);
-  evas_osd_rect->Resize (std::max(evas_osd_text1->Width(), evas_osd_text2->Width()) + 8*HiDPI,
-			 evas_osd_text1->Height() + evas_osd_text2->Height() + 8*HiDPI);
+  evas_osd_text1->Text(str1);
+  evas_osd_text2->Text(str2);
+  evas_osd_text1_shadow->Text(str1);
+  evas_osd_text2_shadow->Text(str2);
   AlphaOSD (0xFF);
   osd_timer.Reset ();
 }
@@ -174,7 +184,8 @@ void Viewer::AlphaOSD (int a)
 {
   evas_osd_text1->Color (0xFF, 0xFF, 0xFF, a);
   evas_osd_text2->Color (0xFF, 0xFF, 0xFF, a);
-  evas_osd_rect->Color (0x40, 0x40, 0x40, std::max (a-92, 0));
+  evas_osd_text1_shadow->Color (0, 0, 0, a);
+  evas_osd_text2_shadow->Color (0, 0, 0, a);
 }
 
 void Viewer::TickOSD ()
@@ -265,10 +276,7 @@ int Viewer::Run (bool opengl)
 
   int xres = 25.4 * XDisplayWidth(dpy, scr) / XDisplayWidthMM(dpy, scr) + .5;
   int yres = 25.4 * XDisplayHeight(dpy, scr) / XDisplayHeightMM(dpy, scr) + .5;
-  if (xres >= 192 || yres >= 192)
-    HiDPI = 2;
-  else if (xres >= 144 || yres >= 144)
-    HiDPI = 1.5;
+  HiDPI = (int)std::min((2 * xres / 96 + .5) / 2.0, (2 * yres / 96 + .5) / 2.0);
   
   attr.backing_store = NotUseful;
   attr.border_pixel = 0;
@@ -408,22 +416,28 @@ int Viewer::Run (bool opengl)
   
   // OSD
   if (!_root) {
+    const int fh = 11;
     evas_osd_text1 = new EvasText (*evas);
     evas_osd_text1->Layer (10);
     evas_osd_text1->Move (4*HiDPI, 4*HiDPI);
-    evas_osd_text1->Font ("Vera", 10*HiDPI);
+    evas_osd_text1->Font ("Vera", fh*HiDPI);
     evas_osd_text1->Show ();
+    evas_osd_text1_shadow = new EvasText (*evas);
+    evas_osd_text1_shadow->Layer (5);
+    evas_osd_text1_shadow->Move (5*HiDPI, 5*HiDPI);
+    evas_osd_text1_shadow->Font ("Vera", fh*HiDPI);
+    evas_osd_text1_shadow->Show ();
     
     evas_osd_text2 = new EvasText (*evas);
     evas_osd_text2->Layer (10);
-    evas_osd_text2->Move (4*HiDPI, 8*HiDPI + evas_osd_text1->Height());
-    evas_osd_text2->Font ("Vera", 10*HiDPI);
+    evas_osd_text2->Move (4*HiDPI, fh*HiDPI + evas_osd_text1->Height());
+    evas_osd_text2->Font ("Vera", fh*HiDPI);
     evas_osd_text2->Show ();
-    
-    evas_osd_rect = new EvasRectangle (*evas);
-    evas_osd_rect->Layer (5);
-    evas_osd_rect->Move (2,2);
-    evas_osd_rect->Show ();
+    evas_osd_text2_shadow = new EvasText (*evas);
+    evas_osd_text2_shadow->Layer (5);
+    evas_osd_text2_shadow->Move (5*HiDPI, (fh+1)*HiDPI + evas_osd_text1->Height());
+    evas_osd_text2_shadow->Font ("Vera", fh*HiDPI);
+    evas_osd_text2_shadow->Show ();
     
     AlphaOSD (0);
   }
@@ -702,7 +716,8 @@ int Viewer::Run (bool opengl)
   
   delete evas_osd_text1; evas_osd_text1 = 0;
   delete evas_osd_text2; evas_osd_text2 = 0;
-  delete evas_osd_rect;  evas_osd_rect = 0;
+  delete evas_osd_text1_shadow; evas_osd_text1_shadow = 0;
+  delete evas_osd_text2_shadow; evas_osd_text2_shadow = 0;
   delete evas_bgr_image; evas_bgr_image = 0;
   
   delete evas;
@@ -720,6 +735,9 @@ bool Viewer::Next ()
     ++it;
     if (it == images.end())
       it = images.begin();
+
+    if (it == ref_it)
+      ++page;
     
     if (Load ())
       return true;
@@ -735,6 +753,10 @@ bool Viewer::Previous ()
     if (it == images.begin())
       it = images.end();
     --it;
+
+    if (it == ref_it)
+      --page;
+
     if (Load ())
       return true;
   }
@@ -749,7 +771,7 @@ bool Viewer::Load ()
   // reset channel filter
   channel = 0;
   
-  if (!ImageCodec::Read(*it, *image)) {
+  if (!ImageCodec::Read(*it, *image, ""/*decompress*/, page)) {
     // TODO: fix to gracefully handle this
     cerr << "Error loading file: " << *it << endl;
     return false;
@@ -916,7 +938,7 @@ int main (int argc, char** argv)
   if (!arglist.Read (argc, argv) || arg_help.Get() == true || arglist.Residuals().empty())
     {
       cerr << "ExactImage viewer - edisplay, version " VERSION << std::endl
-	   << "Copyright (C) 2006 - 2017 René Rebe, ExactCODE GmbH" << std::endl
+	   << "Copyright (C) 2006 - 2020 René Rebe, ExactCODE GmbH" << std::endl
 	   << "Usage:" << endl;
       
       arglist.Usage (cerr);
