@@ -14,7 +14,7 @@ my $image = ExactImage::newImage ();
 
 # easy use, use on-disc files:
 
-if (ExactImage::decodeImageFile ($image, "testsuite/tif/4.2.04.tif"))
+if (ExactImage::decodeImageFile ($image, "testsuite/281-4.2.04.tif"))
 {
 	print "image decoded all fine.\n";
 } else {
