@@ -5,13 +5,14 @@
 
 # add to module search path
 $:.unshift File.dirname(__FILE__) + "/../objdir/api/ruby"
+#$LOAD_PATH.unshift(File.dirname(__FILE__) + "/../objdir/api/ruby")
 
 # load the module
 require 'ExactImage'
 
 image = ExactImage::newImage()
 
-ret = ExactImage::decodeImageFile(image, "../testsuite/230-testimg.jpg")
+ret = ExactImage::decodeImageFile(image, "testsuite/230-testimg.jpg")
 if not ret
   puts 'failed to open image'
 else
