@@ -1,6 +1,6 @@
 /*
  * The ExactImage library's convert compatible command line frontend.
- * Copyright (C) 2005 - 2019 René Rebe, ExactCODE GmbH
+ * Copyright (C) 2005 - 2024 René Rebe, ExactCODE GmbH
  * Copyright (C) 2005, 2008 Archivista GmbH
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -148,7 +148,7 @@ bool convert_input (const Argument<std::string>& arg)
 
 	  int ret = ImageCodec::Read(&stream, *image, cod, decompression, i);
 	  if (ret <= 0) {
-	    std::cerr << "Error reading input file " << arg.Get(j) << ", image: " << i << std::endl;
+	    std::cerr << "Error reading: " << arg.Get(j) << ", image: " << i << std::endl;
 	    delete image;
 	    return false;
 	  }
@@ -1123,7 +1123,7 @@ int main (int argc, char* argv[])
   if (argc == 1 || arg_help.Get() == true)
     {
       std::cerr << "ExactImage converter, version " VERSION << std::endl
-		<< "Copyright (C) 2005 - 2019 René Rebe, ExactCODE GmbH" << std::endl
+		<< "Copyright (C) 2005 - 2024 René Rebe, ExactCODE GmbH" << std::endl
 		<< "Copyright (C) 2005, 2008 Archivista GmbH" << std::endl
 		<< "Usage:" << std::endl;
       
