@@ -1,6 +1,6 @@
 /*
  * The ExactImage library's identify compatible command line frontend.
- * Copyright (C) 2006 - 2017 René Rebe, ExactCODE GmbH
+ * Copyright (C) 2006 - 2023 René Rebe, ExactCODE GmbH
  * Copyright (C) 2006 Archivista
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -75,7 +75,7 @@ int main (int argc, char* argv[])
   if (arg_help.Get() == true || arglist.Residuals().empty())
     {
       std::cerr << "ExactImage identification (edentify), version " VERSION << std::endl
-                << "Copyright (C) 2006 - 2017 René Rebe, ExactCODE GmbH" << std::endl
+                << "Copyright (C) 2006 - 2023 René Rebe, ExactCODE GmbH" << std::endl
                 << "Copyright (C) 2006 Archivista GmbH" << std::endl
                 << "Usage:" << std::endl;
       
@@ -93,7 +93,7 @@ int main (int argc, char* argv[])
       int ret = ImageCodec::Read(*file, image,
 	                         arg_decompression.Size() > 0 ? arg_decompression.Get() : "", i);
       if (ret < 1) {
-	std::cout << "edentify: unable to open image '" << *file << "'." << std::endl;
+	std::cerr << "Error reading: " << *file << std::endl;
 	continue;
       }
       if (i == 0) n = ret;
@@ -195,7 +195,7 @@ int main (int argc, char* argv[])
 		  << (image.getDecoderID().empty() ? "NONE" : image.getDecoderID() )
 		  << " " << image.w << "x" << image.h;
 	
-	if (image.resolutionY() && image.resolutionY())
+	if (image.resolutionX() && image.resolutionY())
 	  std::cout << " @ " << image.resolutionX()
 		    << "x" << image.resolutionY() << "dpi ("
 		    << 254 * image.w / image.resolutionX() / 10 << "x"
