@@ -1,6 +1,6 @@
 /*
  * Colorspace conversions.
- * Copyright (C) 2006 - 2017 René Rebe, ExactCODE GmbH, Germany.
+ * Copyright (C) 2006 - 2023 René Rebe, ExactCODE GmbH, Germany.
  * Copyright (C) 2007 Susanne Klaus, ExactCODE GmbH, Germany.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -266,6 +266,27 @@ void colorspace_rgba8_to_rgb8 (Image& image)
   image.resize(image.w, image.h); // realloc
 }
 
+void colorspace_rgba16_to_rgb16 (Image& image)
+{
+  unsigned ostride = image.stride();
+  image.spp = 3; image.rowstride = 0;
+  
+  for (int y = 0; y < image.h; ++y)
+  {
+    uint16_t* output = (uint16_t*)(image.getRawData() + y * image.stride());
+    uint16_t* it = (uint16_t*)(image.getRawData() + y * ostride);
+    for (int x = 0; x < image.w; ++x)
+    {
+      *output++ = *it++;
+      *output++ = *it++;
+      *output++ = *it++;
+      it++; // skip over a
+    }
+  }
+
+  image.resize(image.w, image.h); // realloc
+}
+
 void colorspace_argb8_to_rgb8 (Image& image)
 {
   uint8_t* data = image.getRawData();
@@ -1049,10 +1070,11 @@ bool colorspace_by_name (Image& image, const std::string& target_colorspace,
     spp = 4; bps = 8;
   } else if (space == "rgb16") {
     spp = 3; bps = 16;
-  // TODO: CYMK, YVU, RGBA, GRAYA...
+  } else if (space == "rgba16") {
+    spp = 4; bps = 16;
+  // TODO: CYMK, YVU, GRAYA...
   } else {
-    std::cerr << "Requested colorspace conversion not yet implemented."
-              << std::endl;
+    std::cerr << "NYI colorspace conversion: " << target_colorspace << std::endl;
     return false;
   }
 
@@ -1096,11 +1118,19 @@ bool colorspace_convert(Image& image, int spp, int bps, uint8_t threshold)
   if (image.bps == 16 && bps < 16)
     colorspace_16_to_8 (image);
   
-  if (image.spp == 4 && spp < 4 && image.bps == 8) { // TODO: might be RGB16
-    if (spp < 3)
-      colorspace_rgb8_to_gray8 (image, 4);
-    else
-      colorspace_rgba8_to_rgb8 (image);
+  // remove alpha channel
+  if (image.spp == 4 && spp < 4) {
+    if (image.bps == 16) {
+      if (spp == 3)
+	colorspace_rgba16_to_rgb16 (image);
+      // TODO: gray
+    }
+    else if (image.bps == 8) {
+      if (spp < 3)
+	colorspace_rgb8_to_gray8 (image, 4);
+      else
+	colorspace_rgba8_to_rgb8 (image);
+    }
   }
 
   if (image.spp == 3 && spp == 4 && image.bps == 8) { // TODO: might be RGB16
@@ -1126,7 +1156,7 @@ bool colorspace_convert(Image& image, int spp, int bps, uint8_t threshold)
   if (image.spp != spp || image.bps != bps) {
     std::cerr << "Incomplete colorspace conversion. Requested: spp: "
               << spp << ", bps: " << bps
-              << " - now at spp: " << image.spp << ", bps: " << image.bps
+              << " - now at spp: " << (int)image.spp << ", bps: " << (int)image.bps
               << std::endl;
     image.spp = spp;
     image.bps = bps;
