@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006 - 2015 René Rebe, ExactCODE GmbH Germany.
+ * Copyright (C) 2006 - 2019 René Rebe, ExactCODE GmbH Germany.
  *           (C) 2006, 2007 Archivista GmbH, CH-8042 Zuerich
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -561,6 +561,7 @@ void box_scale_grayX_to_gray8 (Image& new_image, double scalex, double scaley, b
   Image image;
   image.copyTransferOwnership (new_image);
   
+  new_image.bps = 8;
   new_image.resize (scalex, scaley);
   new_image.setResolution (new_image.w * image.resolutionX() / image.w,
 			   new_image.h * image.resolutionY() / image.h);
@@ -578,8 +579,9 @@ void box_scale_grayX_to_gray8 (Image& new_image, double scalex, double scaley, b
   // pre-compute box indexes
   int bindex [image.w];
 #endif
-  for (int sx = 0; sx < image.w; ++sx)
-    bindex[sx] = std::min ((int)(scalex * sx), new_image.w - 1);
+  for (int sx = 0; sx < image.w; ++sx) {
+    bindex[sx] = sx * new_image.w / image.w;
+  }
   
   const int bps = image.bps;
   const int vmax = 1 << bps;
@@ -588,6 +590,7 @@ void box_scale_grayX_to_gray8 (Image& new_image, double scalex, double scaley, b
 #else
   uint8_t gray_lookup[vmax];
 #endif
+  // TODO: generic shared code for this optimization!
   for (int i = 0; i < vmax; ++i) {
     gray_lookup[i] = 0xff * i / (vmax - 1);
     //std::cerr << i << " = " << (int)gray_lookup[i] << std::endl;
@@ -602,7 +605,9 @@ void box_scale_grayX_to_gray8 (Image& new_image, double scalex, double scaley, b
       memset (&boxes[0], 0, sizeof(boxes));
       memset (&count[0], 0, sizeof(count));
       
-      for (; sy < image.h && sy * scaley < dy + 1; ++sy)
+      for (; sy < image.h &&
+           sy * new_image.h / image.h < dy + 1;
+           ++sy)
 	{
 	  uint8_t z = 0;
 	  unsigned int bits = 0;
